Bip32Type class

Constructors

Bip32Type({required int public, required int private})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
private → int
final
public → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited